==> owncloud-9.0.3.tgz: owncloud/core/l10n/eu.js <==
OC.L10N.register(
    "core",
    {
    "Couldn't send mail to following users: %s " : "Ezin izan da posta bidali hurrengo erabiltzaileei: %s",
    "Turned on maintenance mode" : "Mantenu modua gaitu da",
    "Turned off maintenance mode" : "Mantenu modua desgaitu da",
    "Updated database" : "Datu basea eguneratu da",
    "Checked database schema update" : "Egiaztatuta datu-basearen zerbitzariaren eguneraketa",
    "Checked database schema update for apps" : "Egiaztatuta aplikazioen datu-basearen zerbitzariaren eguneraketa",
    "Updated \"%s\" to %s" : "\"%s\" %s-ra eguneratua",
    "No image or file provided" : "Ez da irudi edo fitxategirik zehaztu",
    "Unknown filetype" : "Fitxategi mota ezezaguna",
    "Invalid image" : "Baliogabeko irudia",
    "No temporary profile picture available, try again" : "Ez dago behin-behineko profil irudirik, saiatu berriro",
    "No crop data provided" : "Ez da ebaketarako daturik zehaztu",
    "Couldn't reset password because the token is invalid" : "Ezin izan da pasahitza berrezarri tokena baliogabea delako",
    "Couldn't send reset email. Please make sure your username is correct." : "Ezin izan da berrezartzeko eposta bidali. Ziurtatu zure erabiltzaile izena egokia dela.",
    "%s password reset" : "%s pasahitza berrezarri",
    "Couldn't send reset email. Please contact your administrator." : "Ezin da berrezartzeko eposta bidali. Mesedez jarri harremetan zure administradorearekin.",
    "Sunday" : "Igandea",
    "Monday" : "Astelehena",
    "Tuesday" : "Asteartea",
    "Wednesday" : "Asteazkena",
    "Thursday" : "Osteguna",
    "Friday" : "Ostirala",
    "Saturday" : "Larunbata",
    "Sun." : "ig.",
    "Mon." : "al.",
    "Tue." : "ar.",
    "Wed." : "az.",
    "Thu." : "og.",
    "Fri." : "ol.",
    "Sat." : "lr.",
    "Su" : "Ig",
    "Sa" : "La",
    "January" : "Urtarrila",
    "February" : "Otsaila",
    "March" : "Martxoa",
    "April" : "Apirila",
    "May" : "Maiatza",
    "June" : "Ekaina",
    "July" : "Uztaila",
    "August" : "Abuztua",
    "September" : "Iraila",
    "October" : "Urria",
    "November" : "Azaroa",
    "December" : "Abendua",
    "Jan." : "urt.",
    "Feb." : "ots.",
    "Mar." : "mar.",
    "Apr." : "api.",
    "May." : "mai.",
    "Jun." : "eka.",
    "Jul." : "uzt.",
    "Aug." : "abu.",
    "Sep." : "ira.",
    "Oct." : "urr.",
    "Nov." : "aza.",
    "Dec." : "abe.",
    "Settings" : "Ezarpenak",
    "Saving..." : "Gordetzen...",
    "seconds ago" : "segundu",
    "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "Zure pasahitza berrezartzeko lotura zure postara bidalia izan da.<br>Ez baduzu arrazoizko denbora epe batean jasotzen begiratu zure zabor-posta karpetan.<br>Hor ere ez badago kudeatzailearekin harremanetan jarri.",
    "Your files are encrypted. If you haven't enabled the recovery key, there will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "Zure fitxategiak enkriptaturik daude. Ez baduzu berreskuratze gakoa gaitzen pasahitza berrabiaraztean ez da zure fitxategiak berreskuratzeko modurik egongo. <br />Zer egin ziur ez bazaude kudeatzailearekin harremanetan ipini jarraitu aurretik.<br /> Ziur zaude aurrera jarraitu nahi duzula?",
    "I know what I'm doing" : "Badakit zer ari naizen egiten",
    "Password can not be changed. Please contact your administrator." : "Ezin da pasahitza aldatu. Mesedez jarri harremetan zure administradorearekin.",
    "No" : "Ez",
    "Yes" : "Bai",
    "Choose" : "Aukeratu",
    "Error loading file picker template: {error}" : "Errorea fitxategi hautatzaile txantiloiak kargatzerakoan: {error}",
    "Ok" : "Ados",
    "Error loading message template: {error}" : "Errorea mezu txantiloia kargatzean: {error}",
    "read-only" : "irakurtzeko-soilik",
    "_{count} file conflict_::_{count} file conflicts_" : ["fitxategi {count}ek konfliktua sortu du","{count} fitxategik konfliktua sortu dute"],
    "One file conflict" : "Fitxategi batek konfliktua sortu du",
    "New Files" : "Fitxategi Berriak",
    "Already existing files" : "Dagoeneko existitzen diren fitxategiak",
    "Which files do you want to keep?" : "Ze fitxategi mantendu nahi duzu?",
    "If you select both versions, the copied file will have a number added to its name." : "Bi bertsioak hautatzen badituzu, kopiatutako fitxategiaren izenean zenbaki bat atxikituko zaio.",
    "Cancel" : "Ezeztatu",
    "Continue" : "Jarraitu",
    "(all selected)" : "(denak hautatuta)",
    "({count} selected)" : "({count} hautatuta)",
    "Error loading file exists template" : "Errorea fitxategia existitzen da txantiloiak kargatzerakoan",
    "Very weak password" : "Pasahitz oso ahula",
    "Weak password" : "Pasahitz ahula",
    "So-so password" : "Halamoduzko pasahitza",
    "Good password" : "Pasahitz ona",
    "Strong password" : "Pasahitz sendoa",
    "Error occurred while checking server setup" : "Errore bat gertatu da zerbitzariaren konfigurazioa egiaztatzerakoan.",
    "Shared" : "Elkarbanatuta",
    "Shared with {recipients}" : "{recipients}-rekin partekatua.",
    "Error" : "Errorea",
    "Error while sharing" : "Errore bat egon da elkarbanatzean",
    "Error while unsharing" : "Errore bat egon da elkarbanaketa desegitean",
    "Error setting expiration date" : "Errore bat egon da muga data ezartzean",
    "The public link will expire no later than {days} days after it is created" : "Esteka publikoak iraungi egingo du, askoz jota, sortu eta  {days} egunetara.",
    "Set expiration date" : "Ezarri muga data",
    "Expiration" : "Iraungitzea",
    "Expiration date" : "Muga data",
    "Choose a password for the public link" : "Aukeratu pasahitz bat esteka publikorako",
    "Sending ..." : "Bidaltzen ...",
    "Email sent" : "Eposta bidalia",
    "Resharing is not allowed" : "Berriz elkarbanatzea ez dago baimendua",
    "Share link" : "Elkarbanatu lotura",
    "Link" : "Esteka",
    "Password protect" : "Babestu pasahitzarekin",
    "Password" : "Pasahitza",
    "Allow editing" : "Baimendu editatzea",
    "Email link to person" : "Postaz bidali lotura ",
    "Send" : "Bidali",
    "Shared with you and the group {group} by {owner}" : "{owner}-k zu eta {group} taldearekin elkarbanatuta",
    "Shared with you by {owner}" : "{owner}-k zurekin elkarbanatuta",
    "group" : "taldea",
    "remote" : "urrunekoa",
    "notify by email" : "jakinarazi eposta bidez",
    "Unshare" : "Ez elkarbanatu",
    "can share" : "elkarbana dezake",
    "can edit" : "editatu dezake",
    "create" : "sortu",
    "change" : "aldatu",
    "delete" : "ezabatu",
    "access control" : "sarrera kontrola",
    "Share" : "Elkarbanatu",
    "Warning" : "Abisua",
    "Delete" : "Ezabatu",
    "Rename" : "Berrizendatu",
    "The object type is not specified." : "Objetu mota ez dago zehaztuta.",
    "Enter new" : "Sartu berria",
    "Add" : "Gehitu",
    "Edit tags" : "Editatu etiketak",
    "Error loading dialog template: {error}" : "Errorea elkarrizketa txantiloia kargatzean: {errorea}",
    "No tags selected for deletion." : "Ez dira ezabatzeko etiketak hautatu.",
    "unknown text" : "testu ezezaguna",
    "Hello world!" : "Kaixo Mundua!",
    "sunny" : "eguzkitsua",
    "Hello {name}, the weather is {weather}" : "Kaixo {name}, eguraldia {weather} da",
    "Hello {name}" : "Kaixo {name}",
    "_download %n file_::_download %n files_" : ["%n fitxategia jaitsi","jaitsi %n fitxategiak"],
    "Updating {productName} to version {version}, this may take a while." : "Eguneratu  {productName} {version} bertsiora, bere denbora behar du.",
    "An error occurred." : "Errore bat gertatu da.",
    "Please reload the page." : "Mesedez birkargatu orria.",
    "The update was unsuccessful. " : "Eguneraketa ongi burutu da.",
    "The update was successful. Redirecting you to ownCloud now." : "Eguneraketa ongi egin da. Orain zure ownClouderea berbideratua izango zara.",
    "Searching other places" : "Beste lekuak bilatzen",
    "No search results in other folders" : "Ez da bilaketaren emaitzik lortu beste karpetatan",
    "Personal" : "Pertsonala",
    "Users" : "Erabiltzaileak",
    "Apps" : "Aplikazioak",
    "Admin" : "Admin",
    "Help" : "Laguntza",
    "Error loading tags" : "Errore bat izan da etiketak kargatzearkoan.",
    "Tag already exists" : "Etiketa dagoeneko existitzen da",
    "Error deleting tag(s)" : "Errore bat izan da etiketa(k) ezabatzerakoan",
    "Error tagging" : "Errorea etiketa ezartzerakoan",
    "Error untagging" : "Errorea etiketa kentzerakoan",
    "Error favoriting" : "Errorea gogokoetara gehitzerakoan",
    "Error unfavoriting" : "Errorea gogokoetatik kentzerakoan",
    "Access forbidden" : "Sarrera debekatuta",
    "File not found" : "Ez da fitxategia aurkitu",
    "The specified document has not been found on the server." : "Zehaztutako dokumentua ez da zerbitzarian aurkitu.",
    "You can click here to return to %s." : "Hemen klika dezakezu %sra itzultzeko.",
    "Hey there,\n\njust letting you know that %s shared %s with you.\nView it: %s\n\n" : "Kaixo\n\n%s-ek %s zurekin partekatu duela jakin dezazun.\nIkusi ezazu: %s\n\n",
    "The share will expire on %s." : "Elkarbanaketa %s-n iraungiko da.",
    "Cheers!" : "Ongi izan!",
    "Internal Server Error" : "Zerbitzariaren Barne Errorea",
    "The server encountered an internal error and was unable to complete your request." : "Zerbitzariak barne errore bat izan du eta ez da gai izan zure eskaria osatzeko.",
    "Please contact the server administrator if this error reappears multiple times, please include the technical details below in your report." : "Mesedez harremanetan jarri zerbitzariaren kudeatzailearekin errore hau aldi askotan agertzekotan, mesedez gehitu beheko zehaztapen teknikoak zure txostenean.",
    "More details can be found in the server log." : "Zehaztapen gehiago zerbitzariaren egunerokoan aurki daitezke.",
    "Technical details" : "Arazo teknikoak",
    "Remote Address: %s" : "Urruneko Helbidea: %s",
    "Request ID: %s" : "Eskariaren IDa: %s",
    "Code: %s" : "Kodea: %s",
    "Message: %s" : "Mezua: %s",
    "File: %s" : "Fitxategia: %s",
    "Line: %s" : "Lerroa: %s",
    "Trace" : "Arrastoa",
    "Security warning" : "Segurtasun abisua",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Zure data karpeta eta fitxategiak interneten bidez eskuragarri egon daitezke .htaccess fitxategia ez delako funtzionatzen ari.",
    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\">documentation</a>." : "Zure zerbitrzaria ongi konfiguratzeko, mezedez <a href=\"%s\" target=\"_blank\">dokumentazioa</a> ikusi.",
    "Create an <strong>admin account</strong>" : "Sortu <strong>kudeatzaile kontu<strong> bat",
    "Username" : "Erabiltzaile izena",
    "Storage & database" : "Biltegia & datubasea",
    "Data folder" : "Datuen karpeta",
    "Configure the database" : "Konfiguratu datu basea",
    "Only %s is available." : "Soilik %s dago eskuragarri.",
    "Database user" : "Datubasearen erabiltzailea",
    "Database password" : "Datubasearen pasahitza",
    "Database name" : "Datubasearen izena",
    "Database tablespace" : "Datu basearen taula-lekua",
    "Database host" : "Datubasearen hostalaria",
    "Finish setup" : "Bukatu konfigurazioa",
    "Finishing …" : "Bukatzen...",
    "Need help?" : "Laguntza behar al duzu?",
    "Hey there,<br><br>just letting you know that %s shared <strong>%s</strong> with you.<br><a href=\"%s\">View it!</a><br><br>" : "Kaixo<br><br>%s-ek %s zurekin partekatu duela jakin dezazun.\nIkusi ezazu: %s",
    "Log out" : "Saioa bukatu",
    "Search" : "Bilatu",
    "Server side authentication failed!" : "Zerbitzari aldeko autentifikazioak huts egin du!",
    "Please contact your administrator." : "Mesedez jarri harremetan zure administradorearekin.",
    "Log in" : "Hasi saioa",
    "Alternative Logins" : "Beste erabiltzaile izenak",
    "Use the following link to reset your password: {link}" : "Eribili hurrengo lotura zure pasahitza berrezartzeko: {link}",
    "New password" : "Pasahitz berria",
    "New Password" : "Pasahitz Berria",
    "Reset password" : "Berrezarri pasahitza",
    "This ownCloud instance is currently in single user mode." : "ownCloud instantzia hau erabiltzaile bakar moduan dago.",
    "This means only administrators can use the instance." : "Honek administradoreak bakarrik erabili dezakeela esan nahi du.",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "Jarri harremanetan zure sistema administratzailearekin mezu hau irauten badu edo bat-batean agertu bada.",
    "Thank you for your patience." : "Milesker zure patzientziagatik.",
    "You are accessing the server from an untrusted domain." : "Zerbitzaria domeinu ez fidagarri batetik eskuratzen ari zara.",
    "Depending on your configuration, as an administrator you might also be able to use the button below to trust this domain." : "Zure ezarpenen gorabehera, administratzaile bezala posible duzu ere azpiko botoia erabiltzea fidatzeko domeinu horrekin.",
    "Add \"%s\" as trusted domain" : "Gehitu \"%s\" domeinu fidagarri gisa",
    "The theme %s has been disabled." : "%s gaia desgaitu da.",
    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Ekin aurretik egiazta ezazu datu basearen, ezarpenen karpetaren eta datuen karpetaren babeskopia duzula.",
    "Start update" : "Hasi eguneraketa",
    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Instalazio handien itxarote-denbora saihesteko, ondoko komandoa exekuta dezakezu instalazio direktoriotik:",
    "This page will refresh itself when the %s instance is available again." : "Orri honek bere burua eguneratuko du %s instantzia berriz prest dagoenean.",
    "Error loading file picker template: {error}" : "Errorea fitxategi hautatzaile txantiloiak kargatzerakoan: {error}",
    "Password can not be changed. Please contact your administrator." : "Ezin da pasahitza aldatu. Mesedez jarri harremetan zure administradorearekin."
},
"nplurals=2; plural=(n != 1);");

==> owncloud-10.0.3.tgz: owncloud/core/l10n/eu.js <==
OC.L10N.register(
    "core",
    {
    "No image or file provided" : "Ez da irudi edo fitxategirik zehaztu",
    "Unknown filetype" : "Fitxategi mota ezezaguna",
    "Invalid image" : "Baliogabeko irudia",
    "No temporary profile picture available, try again" : "Ez dago behin-behineko profil irudirik, saiatu berriro",
    "No crop data provided" : "Ez da ebaketarako daturik zehaztu",
    "Couldn't reset password because the token is invalid" : "Ezin izan da pasahitza berrezarri tokena baliogabea delako",
    "%s password reset" : "%s pasahitza berrezarri",
    "Couldn't send reset email. Please contact your administrator." : "Ezin da berrezartzeko eposta bidali. Mesedez jarri harremetan zure administradorearekin.",
    "Couldn't send mail to following users: %s " : "Ezin izan da posta bidali hurrengo erabiltzaileei: %s",
    "Turned on maintenance mode" : "Mantenu modua gaitu da",
    "Turned off maintenance mode" : "Mantenu modua desgaitu da",
    "Updated database" : "Datu basea eguneratu da",
    "Checked database schema update" : "Egiaztatuta datu-basearen zerbitzariaren eguneraketa",
    "Checked database schema update for apps" : "Egiaztatuta aplikazioen datu-basearen zerbitzariaren eguneraketa",
    "Updated \"%s\" to %s" : "\"%s\" %s-ra eguneratua",
    "Sunday" : "Igandea",
    "Monday" : "Astelehena",
    "Tuesday" : "Asteartea",
    "Wednesday" : "Asteazkena",
    "Thursday" : "Osteguna",
    "Friday" : "Ostirala",
    "Saturday" : "Larunbata",
    "Sun." : "ig.",
    "Mon." : "al.",
    "Tue." : "ar.",
    "Wed." : "az.",
    "Thu." : "og.",
    "Fri." : "ol.",
    "Sat." : "lr.",
    "Su" : "Ig",
    "Sa" : "La",
    "January" : "Urtarrila",
    "February" : "Otsaila",
    "March" : "Martxoa",
    "April" : "Apirila",
    "May" : "Maiatza",
    "June" : "Ekaina",
    "July" : "Uztaila",
    "August" : "Abuztua",
    "September" : "Iraila",
    "October" : "Urria",
    "November" : "Azaroa",
    "December" : "Abendua",
    "Jan." : "urt.",
    "Feb." : "ots.",
    "Mar." : "mar.",
    "Apr." : "api.",
    "May." : "mai.",
    "Jun." : "eka.",
    "Jul." : "uzt.",
    "Aug." : "abu.",
    "Sep." : "ira.",
    "Oct." : "urr.",
    "Nov." : "aza.",
    "Dec." : "abe.",
    "Settings" : "Ezarpenak",
    "Saving..." : "Gordetzen...",
    "seconds ago" : "segundu",
    "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "Zure pasahitza berrezartzeko lotura zure postara bidalia izan da.<br>Ez baduzu arrazoizko denbora epe batean jasotzen begiratu zure zabor-posta karpetan.<br>Hor ere ez badago kudeatzailearekin harremanetan jarri.",
    "Your files are encrypted. If you haven't enabled the recovery key, there will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "Zure fitxategiak enkriptaturik daude. Ez baduzu berreskuratze gakoa gaitzen pasahitza berrabiaraztean ez da zure fitxategiak berreskuratzeko modurik egongo. <br />Zer egin ziur ez bazaude kudeatzailearekin harremanetan ipini jarraitu aurretik.<br /> Ziur zaude aurrera jarraitu nahi duzula?",
    "I know what I'm doing" : "Badakit zer ari naizen egiten",
    "Password can not be changed. Please contact your administrator." : "Ezin da pasahitza aldatu. Mesedez jarri harremetan zure administradorearekin.",
    "No" : "Ez",
    "Yes" : "Bai",
    "Choose" : "Aukeratu",
    "Error loading file picker template: {error}" : "Errorea fitxategi hautatzaile txantiloiak kargatzerakoan: {error}",
    "Ok" : "Ados",
    "Error loading message template: {error}" : "Errorea mezu txantiloia kargatzean: {error}",
    "read-only" : "irakurtzeko-soilik",
    "_{count} file conflict_::_{count} file conflicts_" : ["fitxategi {count}ek konfliktua sortu du","{count} fitxategik konfliktua sortu dute"],
    "One file conflict" : "Fitxategi batek konfliktua sortu du",
    "New Files" : "Fitxategi Berriak",
    "Already existing files" : "Dagoeneko existitzen diren fitxategiak",
    "Which files do you want to keep?" : "Ze fitxategi mantendu nahi duzu?",
    "If you select both versions, the copied file will have a number added to its name." : "Bi bertsioak hautatzen badituzu, kopiatutako fitxategiaren izenean zenbaki bat atxikituko zaio.",
    "Cancel" : "Ezeztatu",
    "Continue" : "Jarraitu",
    "(all selected)" : "(denak hautatuta)",
    "({count} selected)" : "({count} hautatuta)",
    "Error loading file exists template" : "Errorea fitxategia existitzen da txantiloiak kargatzerakoan",
    "Very weak password" : "Pasahitz oso ahula",
    "Weak password" : "Pasahitz ahula",
    "So-so password" : "Halamoduzko pasahitza",
    "Good password" : "Pasahitz ona",
    "Strong password" : "Pasahitz sendoa",
    "Error occurred while checking server setup" : "Errore bat gertatu da zerbitzariaren konfigurazioa egiaztatzerakoan.",
    "Shared" : "Elkarbanatuta",
    "Shared with {recipients}" : "{recipients}-rekin partekatua.",
    "Error" : "Errorea",
    "Error while sharing" : "Errore bat egon da elkarbanatzean",
    "Error while unsharing" : "Errore bat egon da elkarbanaketa desegitean",
    "The public link will expire no later than {days} days after it is created" : "Esteka publikoak iraungi egingo du, askoz jota, sortu eta  {days} egunetara.",
    "Set expiration date" : "Ezarri muga data",
    "Expiration" : "Iraungitzea",
    "Expiration date" : "Muga data",
    "Link" : "Esteka",
    "Edit" : "Editatu",
    "Remove" : "Ezabatu",
    "Choose a password for the public link" : "Aukeratu pasahitz bat esteka publikorako",
    "Password" : "Pasahitza",
    "Name" : "Izena",
    "Allow editing" : "Baimendu editatzea",
    "Save" : "Gorde",
    "Sending ..." : "Bidaltzen ...",
    "Email sent" : "Eposta bidalia",
    "Email link to person" : "Postaz bidali lotura ",
    "Shared with you and the group {group} by {owner}" : "{owner}-k zu eta {group} taldearekin elkarbanatuta",
    "Shared with you by {owner}" : "{owner}-k zurekin elkarbanatuta",
    "group" : "taldea",
    "remote" : "urrunekoa",
    "notify by email" : "jakinarazi eposta bidez",
    "Unshare" : "Ez elkarbanatu",
    "can share" : "elkarbana dezake",
    "can edit" : "editatu dezake",
    "create" : "sortu",
    "change" : "aldatu",
    "delete" : "ezabatu",
    "access control" : "sarrera kontrola",
    "Share" : "Elkarbanatu",
    "Resharing is not allowed" : "Berriz elkarbanatzea ez dago baimendua",
    "Share with people on other ownClouds using the syntax username@example.com/owncloud" : "Partekatu beste ownClud-en jendearekin sintaxi honekin erabiltzaleizena@adibidea.com/owncloud",
    "Warning" : "Abisua",
    "Delete" : "Ezabatu",
    "Rename" : "Berrizendatu",
    "The object type is not specified." : "Objetu mota ez dago zehaztuta.",
    "Enter new" : "Sartu berria",
    "Add" : "Gehitu",
    "Edit tags" : "Editatu etiketak",
    "Error loading dialog template: {error}" : "Errorea elkarrizketa txantiloia kargatzean: {errorea}",
    "No tags selected for deletion." : "Ez dira ezabatzeko etiketak hautatu.",
    "unknown text" : "testu ezezaguna",
    "Hello world!" : "Kaixo Mundua!",
    "sunny" : "eguzkitsua",
    "Hello {name}, the weather is {weather}" : "Kaixo {name}, eguraldia {weather} da",
    "Hello {name}" : "Kaixo {name}",
    "_download %n file_::_download %n files_" : ["%n fitxategia jaitsi","jaitsi %n fitxategiak"],
    "An error occurred." : "Errore bat gertatu da.",
    "Please reload the page." : "Mesedez birkargatu orria.",
    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">ownCloud community</a>." : "Eguneraketa ez da ongi egin. Mesedez egin arazoaren txosten bat <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">ownCloud komunitatearentzako</a>.",
    "The update was successful. Redirecting you to ownCloud now." : "Eguneraketa ongi egin da. Orain zure ownClouderea berbideratua izango zara.",
    "Searching other places" : "Beste lekuak bilatzen",
    "No search results in other folders" : "Ez da bilaketaren emaitzik lortu beste karpetatan",
    "Personal" : "Pertsonala",
    "Users" : "Erabiltzaileak",
    "Apps" : "Aplikazioak",
    "Admin" : "Admin",
    "Help" : "Laguntza",
    "Access forbidden" : "Sarrera debekatuta",
    "File not found" : "Ez da fitxategia aurkitu",
    "The specified document has not been found on the server." : "Zehaztutako dokumentua ez da zerbitzarian aurkitu.",
    "You can click here to return to %s." : "Hemen klika dezakezu %sra itzultzeko.",
    "Hey there,\n\njust letting you know that %s shared %s with you.\nView it: %s\n\n" : "Kaixo\n\n%s-ek %s zurekin partekatu duela jakin dezazun.\nIkusi ezazu: %s\n\n",
    "The share will expire on %s." : "Elkarbanaketa %s-n iraungiko da.",
    "Cheers!" : "Ongi izan!",
    "Internal Server Error" : "Zerbitzariaren Barne Errorea",
    "The server encountered an internal error and was unable to complete your request." : "Zerbitzariak barne errore bat izan du eta ez da gai izan zure eskaria osatzeko.",
    "Please contact the server administrator if this error reappears multiple times, please include the technical details below in your report." : "Mesedez harremanetan jarri zerbitzariaren kudeatzailearekin errore hau aldi askotan agertzekotan, mesedez gehitu beheko zehaztapen teknikoak zure txostenean.",
    "More details can be found in the server log." : "Zehaztapen gehiago zerbitzariaren egunerokoan aurki daitezke.",
    "Technical details" : "Arazo teknikoak",
    "Remote Address: %s" : "Urruneko Helbidea: %s",
    "Request ID: %s" : "Eskariaren IDa: %s",
    "Code: %s" : "Kodea: %s",
    "Message: %s" : "Mezua: %s",
    "File: %s" : "Fitxategia: %s",
    "Line: %s" : "Lerroa: %s",
    "Trace" : "Arrastoa",
    "Create an <strong>admin account</strong>" : "Sortu <strong>kudeatzaile kontu<strong> bat",
    "Username" : "Erabiltzaile izena",
    "Storage & database" : "Biltegia & datubasea",
    "Data folder" : "Datuen karpeta",
    "Configure the database" : "Konfiguratu datu basea",
    "Only %s is available." : "Soilik %s dago eskuragarri.",
    "Database user" : "Datubasearen erabiltzailea",
    "Database password" : "Datubasearen pasahitza",
    "Database name" : "Datubasearen izena",
    "Database tablespace" : "Datu basearen taula-lekua",
    "Database host" : "Datubasearen hostalaria",
    "Finish setup" : "Bukatu konfigurazioa",
    "Finishing …" : "Bukatzen...",
    "Need help?" : "Laguntza behar al duzu?",
    "Hey there,<br><br>just letting you know that %s shared <strong>%s</strong> with you.<br><a href=\"%s\">View it!</a><br><br>" : "Kaixo<br><br>%s-ek %s zurekin partekatu duela jakin dezazun.\nIkusi ezazu: %s",
    "Log out" : "Saioa bukatu",
    "Search" : "Bilatu",
    "Server side authentication failed!" : "Zerbitzari aldeko autentifikazioak huts egin du!",
    "Please contact your administrator." : "Mesedez jarri harremetan zure administradorearekin.",
    "Log in" : "Hasi saioa",
    "Alternative Logins" : "Beste erabiltzaile izenak",
    "Use the following link to reset your password: {link}" : "Eribili hurrengo lotura zure pasahitza berrezartzeko: {link}",
    "New password" : "Pasahitz berria",
    "New Password" : "Pasahitz Berria",
    "Reset password" : "Berrezarri pasahitza",
    "This ownCloud instance is currently in single user mode." : "ownCloud instantzia hau erabiltzaile bakar moduan dago.",
    "This means only administrators can use the instance." : "Honek administradoreak bakarrik erabili dezakeela esan nahi du.",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "Jarri harremanetan zure sistema administratzailearekin mezu hau irauten badu edo bat-batean agertu bada.",
    "Thank you for your patience." : "Milesker zure patzientziagatik.",
    "You are accessing the server from an untrusted domain." : "Zerbitzaria domeinu ez fidagarri batetik eskuratzen ari zara.",
    "Depending on your configuration, as an administrator you might also be able to use the button below to trust this domain." : "Zure ezarpenen gorabehera, administratzaile bezala posible duzu ere azpiko botoia erabiltzea fidatzeko domeinu horrekin.",
    "Add \"%s\" as trusted domain" : "Gehitu \"%s\" domeinu fidagarri gisa",
    "The theme %s has been disabled." : "%s gaia desgaitu da.",
    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Ekin aurretik egiazta ezazu datu basearen, ezarpenen karpetaren eta datuen karpetaren babeskopia duzula.",
    "Start update" : "Hasi eguneraketa",
    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Instalazio handien itxarote-denbora saihesteko, ondoko komandoa exekuta dezakezu instalazio direktoriotik:",
    "This page will refresh itself when the %s instance is available again." : "Orri honek bere burua eguneratuko du %s instantzia berriz prest dagoenean."
},
"nplurals=2; plural=(n != 1);");
